<template>
    <div>
        <Carousel id="gallery" v-model="currentSlide" :items-to-show="1" :wrap-around="false">
            <Slide v-for="image in productImages" :key="image.id">
                <div class="carousel__item">
                    <img :src="image.img" :alt="'Image ' + image.id" />
                </div>
            </Slide>
        </Carousel>

        <Carousel
            id="thumbnails"
            ref="carousel"
            v-model="currentSlide"
            :items-to-show="computedItemsToShow"
            :wrap-around="true"
        >
            <Slide v-for="image in productImages" :key="image.id">
                <div class="carousel__item" @click="slideTo(image.id - 1)">
                    <img :src="image.img" :alt="'Thumbnail ' + image.id" />
                </div>
            </Slide>
        </Carousel>
    </div>
</template>

<script>
import { defineComponent } from "vue";
import { Carousel, Slide } from "vue3-carousel";

import "vue3-carousel/dist/carousel.css";

export default defineComponent({
    name: "ProductImageCarousel",
    components: {
        Carousel,
        Slide,
    },
    props: {
        photos: {
            type: Array,
            required: true,
        },
    },
    data: () => ({
        currentSlide: 0,
        productImages: [],
    }),
    computed: {
        computedItemsToShow() {
            return Math.min(this.photos.length, 3); // Muestra máximo 3, o menos si hay menos fotos
        },
    },
    mounted() {
        if (this.photos.length > 0) {
            this.productImages = this.photos.map((photo) => ({
                id: photo.id,
                img: this.urlDesk(photo.path),
            }));
        } else {
            this.productImages = [{ id: 1, img: "/build/images/web/nophoto.png" }];
        }
    },
    methods: {
        slideTo(val) {
            this.currentSlide = val;
        },
        urlDesk(archivo) {
            // Define la URL base similar a $this->mediaUrl en PHP
            const mediaUrl = "/photos"; // Ajusta esto según tu configuración

            // Extrae el directorio y el nombre del archivo
            const dir = archivo.substring(0, archivo.lastIndexOf("/"));
            const baseName = archivo.substring(archivo.lastIndexOf("/") + 1);

            // Construye la nueva URL
            return `${mediaUrl}/${dir}/desk_${baseName}`;
        },
    },
});
</script>

<style lang="scss">
@use "../scss/variables" as vars;

#gallery {
    border-radius: 8px;
}
</style>
